@@ -1,13 +1,14 @@
 <?php
+
 function blog_add_form() {
 	$html_output = '<div class="blog-admin-add">';
-	$all_languages = getAllLanguages ();
-	$html_output .= "<form action='" . buildSEOUrl ( get_requested_pagename () ) . "?blog_admin=submit' method='post' style=''>";
-	
-	$html_output .= get_csrf_token_html ();
-	
+	$all_languages = getAllLanguages();
+	$html_output .= "<form action='" . buildSEOUrl(get_slug()) . "?blog_admin=submit' method='post' style=''>";
+
+	$html_output .= get_csrf_token_html();
+
 	$html_output .= "<table class='blog_admin_table'>";
-	
+
 	$html_output .= "<tr>";
 	$html_output .= "<td style='width:220px;'>";
 	$html_output .= "<strong>Titel dieser News:</strong>";
@@ -16,38 +17,38 @@ function blog_add_form() {
 	$html_output .= "<input name='title' type='text' maxlength=200 size=40>";
 	$html_output .= "</td>";
 	$html_output .= "</tr>";
-	
+
 	$html_output .= "<tr>";
 	$html_output .= "<td>";
 	$html_output .= "<strong>SEO-URL:</strong>";
 	$html_output .= "</td>";
 	$html_output .= "<td>";
-	$html_output .= "http://" . $_SERVER ["SERVER_NAME"] . "/pfad/zu/ulicms/" . get_requested_pagename () . ".html?single=<input style=<input style='font-weight:bold;background-color:rgb(240, 240, 240);border:0px;' name='seo_shortname' type='text' maxlength=200 size=30>";
+	$html_output .= "http://" . $_SERVER ["SERVER_NAME"] . "/pfad/zu/ulicms/" . get_slug() . ".html?single=<input style=<input style='font-weight:bold;background-color:rgb(240, 240, 240);border:0px;' name='seo_shortname' type='text' maxlength=200 size=30>";
 	$html_output .= "</td>";
 	$html_output .= "</tr>";
-	
+
 	$html_output .= "<tr>";
 	$html_output .= "<td>";
 	$html_output .= "<strong>Sprache des Blogeintrags: </strong>";
 	$html_output .= "</td>";
-	
+
 	$html_output .= "<td>";
 	$html_output .= "<select name='language'>";
-	for($i = 0; $i < count ( $all_languages ); $i ++) {
+	for ($i = 0; $i < count($all_languages); $i ++) {
 		$this_language = $all_languages [$i];
-		$translatedLanguage = getLanguageNameByCode ( $this_language );
-		if (getCurrentLanguage ( false ) == $this_language) {
+		$translatedLanguage = getLanguageNameByCode($this_language);
+		if (getCurrentLanguage(false) == $this_language) {
 			$html_output .= "<option value='$this_language' selected>$translatedLanguage</option>";
 		} else {
 			$html_output .= "<option value='$this_language'>$translatedLanguage</option>";
 		}
 	}
-	
+
 	$html_output .= "</select>";
-	
+
 	$html_output .= "</td>";
 	$html_output .= "</tr>";
-	
+
 	$html_output .= "<tr>";
 	$html_output .= "<td>";
 	$html_output .= "<strong>Blogeintrag aktiviert:</strong>";
@@ -60,7 +61,7 @@ function blog_add_form() {
     ";
 	$html_output .= "</td>";
 	$html_output .= "</tr>";
-	
+
 	$html_output .= "<tr>";
 	$html_output .= "<td>";
 	$html_output .= "<strong>Kommentare aktiviert:</strong>";
@@ -73,67 +74,67 @@ function blog_add_form() {
     ";
 	$html_output .= "</td>";
 	$html_output .= "</tr>";
-	
+
 	$html_output .= "<tr>";
 	$html_output .= "<td>";
 	$html_output .= "<strong>Datum:</strong>";
 	$html_output .= "</td>";
-	
+
 	$html_output .= "<td>";
-	$html_output .= "<strong><input name=\"datum\" type=\"datetime-local\" value=\"" . date ( "Y-m-d\TH:i:s" ) . "\" step=any></strong>";
+	$html_output .= "<strong><input name=\"datum\" type=\"datetime-local\" value=\"" . date("Y-m-d\TH:i:s") . "\" step=any></strong>";
 	$html_output .= "</td>";
-	
+
 	$html_output .= "</tr>";
-	
+
 	$html_output .= "<tr>";
 	$html_output .= "<td><strong>Meta Beschreibung:</strong></td>";
 	$html_output .= "<td><textarea name=\"meta_description\" cols=\"40\" rows=\"3\"></textarea></td>";
 	$html_output .= "</tr>";
-	
+
 	$html_output .= "<tr>";
 	$html_output .= "<td><strong>Meta Keywords:</strong></td>";
 	$html_output .= "<td><textarea name=\"meta_keywords\" cols=\"40\" rows=\"3\"></textarea></td>";
 	$html_output .= "</tr>";
-	
+
 	$html_output .= "<tr>";
 	$html_output .= "<td></td>";
 	$html_output .= "<td align='center'><strong>Inhalt:</strong></td>";
 	$html_output .= "</tr>";
-	
+
 	$html_output .= "<tr>";
 	$html_output .= "<td></td>";
-	
+
 	$html_output .= "<td align='center'>";
-	
+
 	$html_output .= '<textarea name="content_full" id="content_full" cols=60 rows=20></textarea>
 <noscript>
 <p style="color:red;">Der Editor benötigt JavaScript. Bitte aktivieren Sie JavaScript. <a href="http://jumk.de/javascript.html" target="_blank">[Anleitung]</a></p>
 
 </noscript>';
-	
+
 	$html_output .= "</td>";
 	$html_output .= "</tr>";
-	
+
 	$html_output .= "<tr>";
 	$html_output .= "<td></td>";
 	$html_output .= "<td align='center' style='width:98%;'><strong>Vorschau:</strong></td>";
 	$html_output .= "</tr>";
-	
+
 	$html_output .= "<tr>";
 	$html_output .= "<td></td>";
-	
+
 	$html_output .= "<td style='width:98%;' align='center'>";
-	
+
 	$html_output .= '<textarea name="content_preview" id="content_preview" cols=80 rows=20></textarea>
 <noscript>
 <p style="color:red;">Der Editor benötigt JavaScript. Bitte aktivieren Sie JavaScript. <a href="http://jumk.de/javascript.html" target="_blank">[Anleitung]</a></p>
 
 </noscript>';
-	
+
 	$html_output .= "</td>";
-	
+
 	$html_output .= "</tr>";
-	
+
 	$html_output .= "<tr>";
 	$html_output .= "<td>";
 	$html_output .= "</td>";
@@ -141,23 +142,23 @@ function blog_add_form() {
 	$html_output .= "<input type='submit' value='Speichern'>";
 	$html_output .= "</td>";
 	$html_output .= "</tr>";
-	
+
 	$html_output .= "</table>";
-	
+
 	$html_output .= "</form>";
-	
+
 	$html_output .= "<script type=\"text/javascript\">
     
     
 var editor1 = CKEDITOR.replace( 'content_full',
 					{
-						skin : '" . getconfig ( "ckeditor_skin" ) . "'
+						skin : '" . getconfig("ckeditor_skin") . "'
 					});          
 					
 					
 var editor2 = CKEDITOR.replace( 'content_preview',
 					{
-						skin : '" . getconfig ( "ckeditor_skin" ) . "'
+						skin : '" . getconfig("ckeditor_skin") . "'
 					});  
 					
     if(typeof jQuery != \"undefined\"){            
@@ -202,7 +203,7 @@ function confirmExit()
 
 }	
 </script>";
-	
+
 	$html_output .= "
     <style type='text/css'>
     .blog_admin_table tr td{
@@ -227,7 +228,7 @@ function confirmExit()
 
         
     </style>";
-	
+
 	$html_output .= "</div>";
 	return $html_output;
 }
